AGT
===

Components that implement the `Adaptive Gain Theory
<http://www.annualreviews.org/doi/abs/10.1146/annurev.neuro.28.061604.135709>`_ of the function the `locus
coeruleus/norepinephrine system <http://www.scholarpedia.org/article/Locus_coeruleus>`_.

.. toctree::
   :maxdepth: 1

   AGTControlMechanism
   LCControlMechanism

